import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { d as defaultConfig } from './default-ui-config.js';
import { d as defaultIconPack } from './default-icon-pack.js';
import { u as useLanguage } from './index2.js';
import { R as Render } from './index3.js';

const dyteSpotlightGridCss = ":host{display:flex;height:100%;width:100%}main{flex:1 1 0%}aside{width:50%;max-width:var(--dyte-space-96, 384px)}:host([size='sm']),:host([size='md']){flex-direction:column}:host([size='sm']) aside,:host([size='md']) aside{height:50%;max-height:var(--dyte-space-96, 384px);width:100%;max-width:100%}";

const DyteSpotlightGrid$1 = /*@__PURE__*/ proxyCustomElement(class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /** Participants */
    this.participants = [];
    /** Pinned Participants */
    this.pinnedParticipants = [];
    /**
     * Aspect Ratio of participant tile
     *
     * Format: `width:height`
     */
    this.aspectRatio = '16:9';
    /** Gap between participant tiles */
    this.gap = 8;
    /** UI Config */
    this.config = defaultConfig;
    /** Icon Pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
  }
  render() {
    const defaults = {
      meeting: this.meeting,
      config: this.config,
      states: this.states,
      size: this.size,
      iconPack: this.iconPack,
      t: this.t,
    };
    const nonPinnedParticipants = this.participants.filter((p) => !this.pinnedParticipants.includes(p));
    return (h(Host, null, h("main", null, h(Render, { element: "dyte-simple-grid", defaults: defaults, props: {
        participants: this.pinnedParticipants,
        aspectRatio: this.aspectRatio,
        gap: this.gap,
        size: 'md',
      } })), h("aside", null, h(Render, { element: "dyte-simple-grid", defaults: defaults, props: {
        participants: nonPinnedParticipants,
        aspectRatio: this.aspectRatio,
        gap: this.gap,
        size: 'sm',
      } }))));
  }
  get host() { return this; }
  static get style() { return dyteSpotlightGridCss; }
}, [1, "dyte-spotlight-grid", {
    "participants": [16],
    "pinnedParticipants": [16],
    "aspectRatio": [1, "aspect-ratio"],
    "gap": [2],
    "size": [513],
    "meeting": [16],
    "states": [16],
    "config": [16],
    "iconPack": [16],
    "t": [16]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["dyte-spotlight-grid"];
  components.forEach(tagName => { switch (tagName) {
    case "dyte-spotlight-grid":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, DyteSpotlightGrid$1);
      }
      break;
  } });
}

const DyteSpotlightGrid = DyteSpotlightGrid$1;
const defineCustomElement = defineCustomElement$1;

export { DyteSpotlightGrid, defineCustomElement };
