import { r as registerInstance, c as createEvent, h, H as Host } from './index-74ddb327.js';
import { d as defaultIconPack } from './default-icon-pack-eabba256.js';
import { u as useLanguage } from './index-a214afbc.js';
import { s as state, o as onChange } from './store-79928517.js';
import { i as isV2Theme } from './versionTwoApis-e31e770d.js';
import './default-language-04851639.js';

const dyteChatToggleCss = ":host{position:relative;display:block;font-family:var(--dyte-font-family, sans-serif)}.unread-count{position:absolute;right:var(--dyte-space-3, 12px);box-sizing:border-box;padding:var(--dyte-space-0\\.5, 2px);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;--tw-bg-opacity:1;background-color:rgba(var(--dyte-colors-brand-500, 33 96 253) / var(--tw-bg-opacity));font-size:12px;display:flex;height:var(--dyte-space-5, 20px);min-width:var(--dyte-space-5, 20px);align-items:center;justify-content:center;border-radius:9999px;z-index:1}:host([variant='horizontal']){display:flex;flex-direction:row-reverse;align-items:center}:host([variant='horizontal']) .unread-count{right:var(--dyte-space-4, 16px);top:auto}";

const DyteChatToggle = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.stateUpdate = createEvent(this, "dyteStateUpdate", 7);
    this.unreadMessageCount = 0;
    /** Variant */
    this.variant = 'button';
    /** Icon pack */
    this.iconPack = defaultIconPack;
    /** Language */
    this.t = useLanguage();
    this.chatActive = false;
    this.onChatUpdate = ({ action, message }) => {
      var _a;
      if (this.chatActive)
        return;
      if (action === 'add' && message.userId !== ((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.userId)) {
        this.unreadMessageCount += 1;
      }
    };
    this.toggleChat = () => {
      const states = this.states || state;
      this.chatActive = !((states === null || states === void 0 ? void 0 : states.activeSidebar) && (states === null || states === void 0 ? void 0 : states.sidebar) === 'chat');
      if (this.chatActive) {
        this.unreadMessageCount = 0;
      }
      state.activeSidebar = this.chatActive;
      state.sidebar = this.chatActive ? 'chat' : 'none';
      this.stateUpdate.emit({
        activeSidebar: this.chatActive,
        sidebar: this.chatActive ? 'chat' : 'none',
      });
    };
  }
  connectedCallback() {
    this.meetingChanged(this.meeting);
    this.statesChanged(this.states);
    onChange('sidebar', () => this.statesChanged());
  }
  disconnectedCallback() {
    var _a;
    (_a = this.meeting) === null || _a === void 0 ? void 0 : _a.chat.removeListener('chatUpdate', this.onChatUpdate);
  }
  meetingChanged(meeting) {
    if (meeting != null) {
      this.unreadMessageCount = meeting.chat.messages.length;
      meeting.chat.addListener('chatUpdate', this.onChatUpdate);
    }
  }
  statesChanged(s) {
    const states = s || state;
    if (states != null) {
      this.chatActive = states.activeSidebar === true && states.sidebar === 'chat';
    }
  }
  render() {
    var _a;
    // TODO(callmetarush): Just showing chat for all V2 users irrespective of themes
    // untill we get ui theme for V2.
    if (isV2Theme(this.meeting.self.suggestedTheme) ||
      (((_a = this.meeting) === null || _a === void 0 ? void 0 : _a.self.suggestedTheme) &&
        !this.meeting.self.suggestedTheme.controlBar.elements.chat))
      return;
    return (h(Host, { title: this.t('chat') }, this.unreadMessageCount !== 0 && !this.chatActive && (h("div", { class: "unread-count", part: "unread-count" }, h("span", null, this.unreadMessageCount > 99 ? '99+' : this.unreadMessageCount))), h("dyte-controlbar-button", { part: "controlbar-button", size: this.size, iconPack: this.iconPack, class: { active: this.chatActive }, onClick: this.toggleChat, icon: this.iconPack.chat, label: this.t('chat'), variant: this.variant })));
  }
  static get watchers() { return {
    "meeting": ["meetingChanged"],
    "states": ["statesChanged"]
  }; }
};
DyteChatToggle.style = dyteChatToggleCss;

export { DyteChatToggle as dyte_chat_toggle };
